@@ -205,8 +205,8 @@ class Scraper:
     def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0):
         return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout)
 
-    def click(self, path: str, element: any=None, timeout: int=0) -> any:
-        return self.on_click(path=path, element=element, timeout=timeout)
+    def click(self, path: str, element: any=None, timeout: int=0, pos: int=0) -> any:
+        return self.on_click(path=path, element=element, timeout=timeout, pos=pos)
 
     def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
         self.on_click_and_hold(path=path, seconds=seconds, element=element, timeout=timeout)
