@@ -168,7 +168,7 @@ class Selenium(Scraper):
 
     def on_click(self, path: str, element: any=None, timeout: int=0, pos: int=0) -> any:
         if element is None and path is not None:
-            element = self.xPath(path=path, element=element, timeout=timeout)
+            element = self.xPath(path=path, element=element, timeout=timeout, pos=pos)
         
         if element is not None:
             if type(element) is list:
